@@ -16,7 +16,7 @@ use Moo::Role;
 # backward incompatible ways in the future. Please use one of the documented
 # classes instead.
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 requires qw( BUILD format );
 
@@ -224,25 +224,25 @@ sub _validate_number {
     return $num;
 }
 
+my $INF = 9**9**9;
+
 sub _format_number {
     my ($self, $num) = @_;
     my ($format, $num_format);
-    my $bnum = Math::BigFloat->new($num);
 
-    if ($bnum->is_neg) {
+    if ($num < 0) {
         my $pattern = $self->_negative_pattern;
         $pattern =~ s{$M}{$self->minus_sign}e;
         $format = $pattern;
-        $bnum->babs(); # set absolute value
     }
     else {
         $format = $self->_positive_pattern;
     }
 
-    if ($bnum->is_inf) {
+    if ($num == $INF || $num == -$INF) {
         $num_format = $self->infinity;
     }
-    elsif ($bnum->is_nan) {
+    elsif (!defined($num <=> $INF)) {
         $num_format = $self->nan;
     }
     else {
@@ -252,14 +252,15 @@ sub _format_number {
             # TODO: round half to even
             $rounded = Math::Round::nearest(
                 $self->rounding_increment,
-                $bnum->bstr
+                abs $num
             );
         }
         else {
             # round half to even
-            $bnum->round_mode('even');
-            $bnum->ffround(-$self->maximum_fraction_digits);
-            $rounded = $bnum->bstr;
+            $rounded = Math::BigFloat->new($num)->ffround(
+                -$self->maximum_fraction_digits,
+                'even'
+            )->babs->bstr;
         }
 
         my ($int, $frac) = split /\./, $rounded;
